Command

Enum Command 

pub enum Command {
    TestFormat {
        repositories: Option<Vec<PackageRepositories>>,
        file_type: TestFileFormat,
    },
    Download {
        repositories: Option<Vec<PackageRepositories>>,
        source: DownloadCmd,
    },
    Clean {
        target: CleanTarget,
    },
    CompareSrcinfo {
        pkgbuild_path: PathBuf,
        srcinfo_path: PathBuf,
    },
}

Variants



TestFormat

Run tests against a specific file format.

The required data needs to be downloaded up front using “dev-scripts test-files download”.

Fields

repositories: Option<Vec<PackageRepositories>>

Package repositories to test.

If set, tests are limited to the packages that are specified in the databases of these repositories.

If not set, all official repositories are tested, which for SRCINFO includes the AUR.

file_type: TestFileFormat

The type of file that should be tested.



Download

Download/synchronize files for testing to this machine.

Each type of file can be downloaded individually.

Fields

repositories: Option<Vec<PackageRepositories>>

Package repositories to download.

If not set, all official repositories are downloaded.



Clean

Remove or clean downloaded local testing files.

Fields



CompareSrcinfo

Run the alpm-pkgbuild srcinfo format command on a PKGBUILD and compare its output with a given .SRCINFO file.

Fields

pkgbuild_path: PathBuf

Path to the PKGBUILD file.

srcinfo_path: PathBuf

Path to the .SRCINFO file.